This is a plugin for ofxstatement to parse and convert proprietary bank statements of certain banks in Latvian to OFX files.

Statements from these banks are currently supported:

* Swedbank - CSV files
* DNB - FIDAVISTA xml files
